import { BodyProps, BoxProps, CannonWorkerAPI, CompoundBodyProps, ConvexPolyhedronArgs, CylinderArgs, HeightfieldArgs, ParticleProps, PlaneProps, PropValue, SphereArgs, SubscriptionName, SubscriptionTarget, Subscriptions, TrimeshArgs, Triplet } from '@pmndrs/cannon-worker-api';
import { NgtcCannonEvents, NgtcPhysics } from 'angular-three-cannon';
import { Object3D } from 'three';
import { NgtcWorkerApi } from './types';
export declare function createSubscribe<T extends SubscriptionName>(body: Object3D, worker: CannonWorkerAPI, subscriptions: Subscriptions, type: T, index?: number, target?: SubscriptionTarget): (callback: (value: PropValue<T>) => void) => () => void;
export declare function prepare(object: Object3D, { position, rotation, userData }: BodyProps): void;
export declare function setupCollision(events: NgtcCannonEvents, { onCollide, onCollideBegin, onCollideEnd }: Partial<BodyProps>, uuid: string): void;
export declare function makeBodyApi(body: Object3D, worker: CannonWorkerAPI, { subscriptions, scaleOverrides }: Pick<NgtcPhysics, 'subscriptions' | 'scaleOverrides'>): {
    at: (index: number) => NgtcWorkerApi;
    allowSleep: import("angular-three-cannon/body").NgtcAtomicApi<"allowSleep">;
    angularDamping: import("angular-three-cannon/body").NgtcAtomicApi<"angularDamping">;
    collisionFilterGroup: import("angular-three-cannon/body").NgtcAtomicApi<"collisionFilterGroup">;
    collisionFilterMask: import("angular-three-cannon/body").NgtcAtomicApi<"collisionFilterMask">;
    collisionResponse: import("angular-three-cannon/body").NgtcAtomicApi<"collisionResponse">;
    fixedRotation: import("angular-three-cannon/body").NgtcAtomicApi<"fixedRotation">;
    isTrigger: import("angular-three-cannon/body").NgtcAtomicApi<"isTrigger">;
    linearDamping: import("angular-three-cannon/body").NgtcAtomicApi<"linearDamping">;
    mass: import("angular-three-cannon/body").NgtcAtomicApi<"mass">;
    material: import("angular-three-cannon/body").NgtcAtomicApi<"material">;
    sleepSpeedLimit: import("angular-three-cannon/body").NgtcAtomicApi<"sleepSpeedLimit">;
    sleepTimeLimit: import("angular-three-cannon/body").NgtcAtomicApi<"sleepTimeLimit">;
    userData: import("angular-three-cannon/body").NgtcAtomicApi<"userData">;
    angularFactor: import("angular-three-cannon/body").NgtcVectorApi;
    angularVelocity: import("angular-three-cannon/body").NgtcVectorApi;
    linearFactor: import("angular-three-cannon/body").NgtcVectorApi;
    position: import("angular-three-cannon/body").NgtcVectorApi;
    velocity: import("angular-three-cannon/body").NgtcVectorApi;
    applyForce: (force: Triplet, worldPoint: Triplet) => void;
    applyImpulse: (impulse: Triplet, worldPoint: Triplet) => void;
    applyLocalForce: (force: Triplet, localPoint: Triplet) => void;
    applyLocalImpulse: (impulse: Triplet, localPoint: Triplet) => void;
    applyTorque: (torque: Triplet) => void;
    quaternion: import("angular-three-cannon/body").NgtcQuaternionApi;
    rotation: import("angular-three-cannon/body").NgtcVectorApi;
    scaleOverride: (scale: Triplet) => void;
    sleep: () => void;
    wakeUp: () => void;
    remove: () => void;
};
export declare const defaultTransformArgs: {
    Plane: (_: PlaneProps["args"]) => never[];
    Box: (args?: BoxProps["args"]) => Triplet;
    Trimesh: (args: TrimeshArgs) => TrimeshArgs;
    Cylinder: (_?: CylinderArgs) => never[];
    Heightfield: (args: HeightfieldArgs) => HeightfieldArgs;
    ConvexPolyhedron: ([vertices, faces, normals, axes, boundingSphereRadius]?: ConvexPolyhedronArgs) => (number | number[][] | undefined)[];
    Particle: (_: ParticleProps["args"]) => never[];
    Sphere: (args?: SphereArgs) => number[];
    Compound: (args: CompoundBodyProps["args"]) => unknown[] | undefined;
};
