import { ElementRef, Injector, Signal } from '@angular/core';
import { ConeTwistConstraintOpts, ConstraintTypes, DistanceConstraintOpts, HingeConstraintOpts, LockConstraintOpts, PointToPointConstraintOpts } from '@pmndrs/cannon-worker-api';
import { Object3D } from 'three';
export interface NgtcConstraintApi {
    disable: () => void;
    enable: () => void;
    remove: () => void;
}
export interface NgtcHingeConstraintApi extends NgtcConstraintApi {
    disableMotor: () => void;
    enableMotor: () => void;
    setMotorMaxForce: (value: number) => void;
    setMotorSpeed: (value: number) => void;
}
export type NgtcConstraintORHingeApi<T extends 'Hinge' | ConstraintTypes> = T extends ConstraintTypes ? NgtcConstraintApi : NgtcHingeConstraintApi;
export type NgtcConstraintOptionsMap = {
    ConeTwist: ConeTwistConstraintOpts;
    PointToPoint: PointToPointConstraintOpts;
    Distance: DistanceConstraintOpts;
    Lock: LockConstraintOpts;
    Hinge: HingeConstraintOpts;
};
export type NgtcConstraintOptions<TConstraintType extends 'Hinge' | ConstraintTypes> = {
    injector?: Injector;
    disableOnStart?: boolean;
    options?: NgtcConstraintOptionsMap[TConstraintType];
};
export declare const injectPointToPoint: <A extends Object3D = Object3D<import("three").Object3DEventMap>, B extends Object3D = Object3D<import("three").Object3DEventMap>>(bodyA: A | ElementRef<A> | Signal<A | ElementRef<A> | undefined>, bodyB: B | ElementRef<B> | Signal<B | ElementRef<B> | undefined>, options?: NgtcConstraintOptions<"PointToPoint"> | undefined) => Signal<NgtcConstraintApi | null>;
export declare const injectConeTwist: <A extends Object3D = Object3D<import("three").Object3DEventMap>, B extends Object3D = Object3D<import("three").Object3DEventMap>>(bodyA: A | ElementRef<A> | Signal<A | ElementRef<A> | undefined>, bodyB: B | ElementRef<B> | Signal<B | ElementRef<B> | undefined>, options?: NgtcConstraintOptions<"ConeTwist"> | undefined) => Signal<NgtcConstraintApi | null>;
export declare const injectDistance: <A extends Object3D = Object3D<import("three").Object3DEventMap>, B extends Object3D = Object3D<import("three").Object3DEventMap>>(bodyA: A | ElementRef<A> | Signal<A | ElementRef<A> | undefined>, bodyB: B | ElementRef<B> | Signal<B | ElementRef<B> | undefined>, options?: NgtcConstraintOptions<"Distance"> | undefined) => Signal<NgtcConstraintApi | null>;
export declare const injectLock: <A extends Object3D = Object3D<import("three").Object3DEventMap>, B extends Object3D = Object3D<import("three").Object3DEventMap>>(bodyA: A | ElementRef<A> | Signal<A | ElementRef<A> | undefined>, bodyB: B | ElementRef<B> | Signal<B | ElementRef<B> | undefined>, options?: NgtcConstraintOptions<"Lock"> | undefined) => Signal<NgtcConstraintApi | null>;
export declare const injectHinge: <A extends Object3D = Object3D<import("three").Object3DEventMap>, B extends Object3D = Object3D<import("three").Object3DEventMap>>(bodyA: A | ElementRef<A> | Signal<A | ElementRef<A> | undefined>, bodyB: B | ElementRef<B> | Signal<B | ElementRef<B> | undefined>, options?: NgtcConstraintOptions<"Hinge"> | undefined) => Signal<NgtcConstraintApi | null>;
