import * as i0 from '@angular/core';
import { inject, input, afterNextRender, Directive } from '@angular/core';
import { propsToBody } from '@pmndrs/cannon-worker-api';
import { injectStore, injectBeforeRender } from 'angular-three';
import { NgtcPhysics } from 'angular-three-cannon';
import CannonDebugger from 'cannon-es-debugger';
import { mergeInputs } from 'ngxtension/inject-inputs';
import { Quaternion, Vector3, Matrix4, InstancedMesh, Scene } from 'three';

const q = new Quaternion();
const s = new Vector3(1, 1, 1);
const v = new Vector3();
const m = new Matrix4();
function getMatrix(o) {
    if (o instanceof InstancedMesh) {
        o.getMatrixAt(parseInt(o.uuid.split('/')[1]), m);
        return m;
    }
    return o.matrix;
}
const defaultOptions = {
    enabled: true,
    scale: 1,
    color: 'black',
    impl: CannonDebugger,
};
class NgtcDebug {
    constructor() {
        this.store = injectStore();
        this.physics = inject(NgtcPhysics);
        this.debug = input(defaultOptions, { transform: mergeInputs(defaultOptions) });
        this.defaultScene = this.store.select('scene');
        this.debuggerScene = new Scene();
        this.bodies = [];
        this.bodyMap = {};
        // NOTE: afterNextRender so we only instantiate once after inputs have been resolved
        afterNextRender(() => {
            this.defaultScene().add(this.debuggerScene);
            this.cannonDebugger = this.debug().impl(this.debuggerScene, { bodies: this.bodies }, {
                color: this.debug().color,
                scale: this.debug().scale,
            });
        });
        injectBeforeRender(() => {
            if (!this.cannonDebugger)
                return;
            const enabled = this.debug().enabled;
            const refs = this.physics.refs;
            for (const uuid in this.bodyMap) {
                const ref = refs[uuid];
                const body = this.bodyMap[uuid];
                if (ref) {
                    getMatrix(ref).decompose(v, q, s);
                    body.position.copy(v);
                    body.quaternion.copy(q);
                }
            }
            for (const child of this.debuggerScene.children)
                child.visible = enabled;
            if (enabled)
                this.cannonDebugger.update();
        });
    }
    add(uuid, props, type) {
        const body = propsToBody({ uuid, props, type });
        this.bodies.push(body);
        this.bodyMap[uuid] = body;
    }
    remove(uuid) {
        const debugBodyIndex = this.bodies.indexOf(this.bodyMap[uuid]);
        if (debugBodyIndex > -1)
            this.bodies.splice(debugBodyIndex, 1);
        delete this.bodyMap[uuid];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: NgtcDebug, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.1.4", type: NgtcDebug, isStandalone: true, selector: "ngtc-physics[debug]", inputs: { debug: { classPropertyName: "debug", publicName: "debug", isSignal: true, isRequired: false, transformFunction: null } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.1.4", ngImport: i0, type: NgtcDebug, decorators: [{
            type: Directive,
            args: [{ selector: 'ngtc-physics[debug]' }]
        }], ctorParameters: () => [] });

/**
 * Generated bundle index. Do not edit.
 */

export { NgtcDebug };
//# sourceMappingURL=angular-three-cannon-debug.mjs.map
