import { CannonWorkerAPI, CannonWorkerProps, CollideBeginEvent, CollideEndEvent, CollideEvent, RayhitEvent, Refs, Subscriptions, WorkerCollideBeginEvent, WorkerCollideEndEvent, WorkerCollideEvent, WorkerFrameMessage, WorkerRayhitEvent } from '@pmndrs/cannon-worker-api';
import { Vector3 } from 'three';
import * as i0 from "@angular/core";
export interface NgtcCannonWorkerEvents {
    collide: WorkerCollideEvent;
    collideBegin: WorkerCollideBeginEvent;
    collideEnd: WorkerCollideEndEvent;
    frame: WorkerFrameMessage;
    rayhit: WorkerRayhitEvent;
}
export type NgtcCannonWorker = CannonWorkerAPI & {
    on: <K extends keyof NgtcCannonWorkerEvents>(event: K, cb: (data: NgtcCannonWorkerEvents[K]['data']) => void) => void;
    removeAllListeners: () => void;
};
type NgtcCannonEvent = CollideBeginEvent | CollideEndEvent | CollideEvent | RayhitEvent;
type NgtcCallbackByType<T extends {
    type: string;
}> = {
    [K in T['type']]?: T extends {
        type: K;
    } ? (e: T) => void : never;
};
export type NgtcCannonEvents = Record<string, Partial<NgtcCallbackByType<NgtcCannonEvent>>>;
export type ScaleOverrides = Record<string, Vector3>;
export interface NgtcPhysicsOptions extends CannonWorkerProps {
    isPaused?: boolean;
    maxSubSteps?: number;
    shouldInvalidate?: boolean;
    stepSize?: number;
}
export declare class NgtcPhysics {
    private store;
    options: import("@angular/core").InputSignalWithTransform<NgtcPhysicsOptions, "" | Partial<NgtcPhysicsOptions>>;
    private axisIndex;
    private broadphase;
    private gravity;
    private iterations;
    private tolerance;
    private invalidate;
    private cannonWorker;
    bodies: {
        [uuid: string]: number;
    };
    events: NgtcCannonEvents;
    refs: Refs;
    scaleOverrides: ScaleOverrides;
    subscriptions: Subscriptions;
    worker: import("@angular/core").Signal<CannonWorkerAPI>;
    constructor();
    private connectWorkerEffect;
    private updateWorkerStateEffect;
    private collideHandler;
    private collideBeginHandler;
    private collideEndHandler;
    private frameHandler;
    private rayhitHandler;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgtcPhysics, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgtcPhysics, "ngtc-physics", never, { "options": { "alias": "options"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}
export {};
